@@ -58,3 +58,10 @@ def get_iamge():
     screen_shot('android',None)
     crop()
 
+def element_click(element_keywords_name):
+    a='self.driver.'
+    b='(value).click()'
+    c=a+element_keywords_name+b
+    eval(c)
+
+
